@@ -449,6 +449,8 @@ private:
   mutable WContainerWidget *footer_;
   bool modal_, resizable_, movable_, escapeIsReject_, autoFocus_;
   JSignal<int,int> moved_, resized_;
+  JSignal<int> zIndexChanged_;
+  std::vector<std::string> delayedJs_;
 
   Signal<DialogCode> finished_;
   DialogCode result_;
@@ -461,6 +463,9 @@ private:
   void onEscapePressed();
   void onDefaultPressed();
   void bringToFront(const WMouseEvent &e);
+  void zIndexChanged(int zIndex);
+
+  void doJSAfterLoad(std::string js);
 
   DialogCover *cover();
 
